==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coreimage/CIDetector.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coreimage;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.opengles.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.imageio.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("CoreImage") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CIDetector/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CIDetectorPtr extends Ptr<CIDetector, CIDetectorPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CIDetector.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CIDetector() {}
    protected CIDetector(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    
    public CIDetector(CIDetectorType type, CIContext context, CIDetectorOptions options) {
        super(init(type, context, options));
    }
    
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    /**
     * @since Available in iOS 5.0 and later.
     */
    @Method(selector = "featuresInImage:")
    public native NSArray<CIFeature> findFeatures(CIImage image);
    /**
     * @since Available in iOS 5.0 and later.
     */
    @Method(selector = "featuresInImage:options:")
    public native NSArray<CIFeature> findFeatures(CIImage image, CIDetectorFeatureOptions options);
    /**
     * @since Available in iOS 5.0 and later.
     */
    @Method(selector = "detectorOfType:context:options:")
    protected static native @Pointer long init(CIDetectorType type, CIContext context, CIDetectorOptions options);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/coreimage/CIDetector.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coreimage;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.opengles.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.imageio.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.metal.*;
import org.robovm.apple.iosurface.*;
import org.robovm.apple.avfoundation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("CoreImage") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CIDetector/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CIDetectorPtr extends Ptr<CIDetector, CIDetectorPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CIDetector.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CIDetector() {}
    protected CIDetector(Handle h, long handle) { super(h, handle); }
    protected CIDetector(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    
    public CIDetector(CIDetectorType type, CIContext context, CIDetectorOptions options) {
        super(init(type, context, options));
    }
    
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "featuresInImage:")
    public native NSArray<CIFeature> findFeatures(CIImage image);
    @Method(selector = "featuresInImage:options:")
    public native NSArray<CIFeature> findFeatures(CIImage image, CIDetectorFeatureOptions options);
    @Method(selector = "detectorOfType:context:options:")
    protected static native @Pointer long init(CIDetectorType type, CIContext context, CIDetectorOptions options);
    /*</methods>*/
}
